@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 0.0.5 $
-### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
+### $Release: 0.6.0 $
+### copyright(c) 2008-2011 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
@@ -55,9 +55,9 @@ class Kitchen(object):
                 elif exists(target):  cookable = Material.new(target)
                 else:
                     if parent_product:
-                        raise KookRecipeError("%s: no such recipe or material (required for %s)." % (target, repr(parent_product)))
+                        raise KookRecipeError("%s: no such recipe nor material (required for %s)." % (target, repr(parent_product)))
                     else:
-                        raise KookRecipeError("%s: no such recipe or material." % target)
+                        raise KookRecipeError("%s: no such recipe nor material." % target)
             assert cookable is not None
             cookables[target] = cookable
             if cookable.ingreds:
@@ -139,9 +139,9 @@ class Cookable(object):
         raise NotImplementedError("%s.has_product_file(): not implemented yet." % self.__class__.__name__)
 
 
-CONTENT_CHANGED = 3     # recipe is invoked, and product content is changed when recipe is FileRecipe
-MTIME_UPDATED   = 2     # file content of product is not changed (recipe may be invoked or not)
-NOT_INVOKED     = 1     # recipe is not invoked (= skipped), for example product is newer than all ingredients
+CHANGED = 3     # recipe is invoked, and product content is changed when recipe is FileRecipe
+TOUCHED = 2     # file content of product is not changed (recipe may be invoked or not)
+SKIPPED = 1     # recipe is not invoked (= skipped), for example product is newer than all ingredients
 
 
 class Material(Cookable):
@@ -157,7 +157,7 @@ class Material(Cookable):
     def cook(self, depth=1, argv=()):
         assert os.path.exists(self.product)
         _debug("material %s" % self.product, depth)
-        return NOT_INVOKED
+        return SKIPPED
 
     def has_product_file(self):
         return True
@@ -166,17 +166,19 @@ class Material(Cookable):
 class Cooking(Cookable):
     """represens recipe invocation. in other words, Recipe is 'definition', Cooking is 'execution'."""
 
-    def __init__(self, recipe, product=None, ingreds=None, byprods=None, spices=None):
+    def __init__(self, recipe, product=None, ingreds=None, byprods=None, spices=None, matched=None, m=None):
         if product is None: product = recipe.product
-        if ingreds is None: ingreds = recipe.ingreds
-        if byprods is None: byprods = recipe.byprods
-        if spices  is None: spices  = recipe.spices
+        if ingreds is None: ingreds = recipe.ingreds or ()
+        if byprods is None: byprods = recipe.byprods or ()
+        if spices  is None: spices  = recipe.spices  or ()
         self.recipe  = recipe
         self.product = product
         self.ingreds = ingreds
         self.byprods = byprods
         self.ingred  = ingreds and ingreds[0] or None
         self.byprod  = byprods and byprods[0] or None
+        self.matched = matched
+        self.m       = m
         self.children = []       # child cookables
         self.spices  = spices
         self.cooked  = None
@@ -186,34 +188,15 @@ class Cooking(Cookable):
     @classmethod
     def new(cls, target, recipe):
         product = target
+        matched = m = None
+        if recipe.is_generic():
+            recipe  = recipe._to_specific(product)
+            matched = recipe._matched
+            m = recipe._m
         ingreds = recipe.ingreds or ()
         byprods = recipe.byprods or ()
         spices  = recipe.spices  or ()
-        if recipe.pattern:
-            ## convert generic recipe into specific values
-            matched = re.match(recipe.pattern, target)
-            assert matched is not None
-            pat = r'\$\((\d+)\)'   # replace '$(1)', '$(2)', ...
-            repl = lambda m: matched.group(int(m.group(1)))
-            def convert(items):
-                arr = []
-                for item in items:
-                    if isinstance(item, ConditionalFile):
-                        filename = re.sub(pat, repl, item.filename)
-                        filename = item.__call__(filename)
-                        if filename: arr.append(filename)
-                    else:
-                        arr.append(re.sub(pat, repl, item))
-                return tuple(arr)
-            if ingreds:  ingreds = convert(ingreds)
-            if byprods:  byprods = convert(byprods)
-            m = (matched.group(), ) + matched.groups()   # tuple
-        else:
-            matched = None
-            m = None
-        self = cls(recipe, product=product, ingreds=ingreds, byprods=byprods, spices=spices)
-        self.matched = matched
-        self.m = m
+        self = cls(recipe, product=product, matched=matched, m=m)
         return self
 
     def has_product_file(self):
@@ -225,16 +208,16 @@ class Cooking(Cookable):
     ##   if CONENT_CHANGED in self.children:
     ##     invoke recipe
     ##     if new content is same as old:
-    ##       return MTIME_UPDATED
+    ##       return TOUCHED
     ##     else:
-    ##       return CONTENT_CHANGED
-    ##   elif MTIME_UPDATED in self.children:
+    ##       return CHANGED
+    ##   elif TOUCHED in self.children:
     ##     # not invoke recipe function
     ##     touch product file
-    ##     return MTIME_UPDATED
+    ##     return TOUCHED
     ##   else:
     ##     # not invoke recipe function
-    ##     return NOT_INVOKED
+    ##     return SKIPPED
     ##
     def cook(self, depth=1, argv=()):
         """invoke recipe function."""
@@ -250,43 +233,31 @@ class Cooking(Cookable):
         else:
             product_mtime = 0    # product doesn't exist
         ## invoke ingredients' recipes
-        child_status = NOT_INVOKED
+        child_status = SKIPPED
         if self.children:
             for child in self.children:
                 ret = child.cook(depth+1, ())
                 assert ret is not None
                 if ret > child_status:  child_status = ret
-                if product_mtime and ret == NOT_INVOKED and child.has_product_file():
+                if product_mtime and ret == SKIPPED and child.has_product_file():
                     assert os.path.exists(child.product)
                     if os.path.getmtime(child.product) > product_mtime:
                         _trace("child file '%s' is newer than product '%s'." % (child.product, self.product), depth)
-                        child_status = CONTENT_CHANGED
-        assert child_status in (CONTENT_CHANGED, MTIME_UPDATED, NOT_INVOKED)
+                        child_status = CHANGED
+        assert child_status in (CHANGED, TOUCHED, SKIPPED)
         ## there are some cases to skip recipe invocation (ex. product is newer than ingredients)
         if self._can_skip(child_status, depth):
-            if child_status == MTIME_UPDATED:
-                assert os.path.exists(self.product)
-                _report_msg("%s (%s)" % (self.product, self._r), depth)
-                _debug("touch and skip %s (%s)" % (self.product, self._r), depth)
-                _report_cmd("touch %s   # skipped" % self.product)
-                os.utime(self.product, None)    # update mtime of product file to current timestamp
-                self.cooked = MTIME_UPDATED
-                return MTIME_UPDATED    # skip recipe invocation
-            elif child_status == NOT_INVOKED:
-                _debug("skip %s (%s)" % (self.product, self._r), depth)
-                self.cooked = NOT_INVOKED
-                return NOT_INVOKED          # skip recipe invocation
-            else:
-                assert child_status == CONTENT_CHANGED
-                pass    # don't skip recipe invocation
+            assert child_status == TOUCHED or child_status == SKIPPED
+            self._skip(child_status, depth)
+            self.cooked = child_status
+            return child_status
         ## invoke recipe function
-        assert self.recipe.func is not None
+        assert self.recipe.method is not None
         try:
             try:
                 ## if product file exists, rename it to temporary filename
                 if product_mtime:
-                    tmp_basename = ".kook.%s.kook" % os.path.basename(self.product)
-                    tmp_filename = os.path.join(os.path.dirname(self.product), tmp_basename)
+                    tmp_filename = self._tmp_filename(self.product)
                     os.rename(self.product, tmp_filename)
                 ## invoke recipe
                 s = is_file_recipe and 'create' or 'perform'
@@ -296,14 +267,14 @@ class Cooking(Cookable):
                 ## check whether product file created or not
                 if is_file_recipe and not config.noexec and not os.path.exists(self.product):
                     raise KookRecipeError("%s: product not created (in %s())." % (self.product, self.recipe.name, ))
-                ## if new product file is same as old, return MTIME_UPDATED, else return CONTENT_CHANGED
+                ## if new product file is same as old one, return TOUCHED, else return CHANGED
                 if config.compare_contents and product_mtime and kook.utils.has_same_content(self.product, tmp_filename):
-                    ret, msg = MTIME_UPDATED,   "end %s (content not changed, mtime updated)"
+                    _debug("end %s (content not changed, mtime updated)" % self.product, depth)
+                    self.cooked = TOUCHED
                 else:
-                    ret, msg = CONTENT_CHANGED, "end %s (content changed)"
-                _debug(msg % self.product, depth)
-                self.cooked = ret
-                return ret
+                    _debug("end %s (content changed)" % self.product, depth)
+                    self.cooked = CHANGED
+                return self.cooked
             except Exception:
                 ## if product file exists, remove it when error raised
                 if product_mtime:
@@ -311,6 +282,7 @@ class Cooking(Cookable):
                     if os.path.isfile(self.product): os.unlink(self.product)
                 raise
         finally:
+            ## remove temporary file
             if product_mtime: os.unlink(tmp_filename)
 
     def _can_skip(self, child_status, depth):
@@ -327,10 +299,10 @@ class Cooking(Cookable):
             _trace("cannot skip: product '%s' not found." % self.product, depth)
             return False
         ##
-        if child_status == CONTENT_CHANGED:
+        if child_status == CHANGED:
             _trace("cannot skip: there is newer file in children than product '%s'." % self.product, depth)
             return False
-        #if child_status == NOT_INVOKED:
+        #if child_status == SKIPPED:
         #    timestamp = os.path.getmtime(self.product)
         #    for child in self.children:
         #        if child.has_product_file() and os.path.getmtime(child.product) > timestamp:
@@ -339,12 +311,29 @@ class Cooking(Cookable):
         ##
         return True
 
+    def _skip(self, child_status, depth):
+        if child_status == TOUCHED:
+            assert os.path.exists(self.product)
+            _report_msg("%s (%s)" % (self.product, self._r), depth)
+            _debug("touch and skip %s (%s)" % (self.product, self._r), depth)
+            _report_cmd("touch %s   # skipped" % self.product)
+            os.utime(self.product, None)    # update mtime of product file to current timestamp
+        elif child_status == SKIPPED:
+            _debug("skip %s (%s)" % (self.product, self._r), depth)
+        else:
+            assert 'unreachable'
+
+    def _tmp_filename(self, filename):
+        tmp_basename = ".kook.%s.kook" % os.path.basename(filename)
+        tmp_filename = os.path.join(os.path.dirname(filename), tmp_basename)
+        return tmp_filename
+
     def _invoke_recipe_with(self, argv):
         if self.spices:
             opts, rests = self.parse_cmdopts(argv)
-            self.recipe.func(self, *rests, **opts)
+            self.recipe.method(self, *rests, **opts)
         else:
-            self.recipe.func(self, *argv)
+            self.recipe.method(self, *argv)
 
     ## utility method for convenience
     def __mod__(self, string):
