@@ -1,6 +1,6 @@
 ###
-### $Release: 0.0.5 $
-### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
+### $Release: 0.6.0 $
+### copyright(c) 2008-2011 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
@@ -76,7 +76,7 @@ char *command = "hello";
 
 class KookMainCommandTest(object):
 
-    def before_each(self):
+    def before(self):
         self._currdir = os.getcwd()
         self._tmpdir  = str(random.random())
         os.mkdir(self._tmpdir)
@@ -85,7 +85,7 @@ class KookMainCommandTest(object):
         write_file('hello.c', HELLO_C)
         write_file('hello.h', HELLO_H)
 
-    def after_each(self):
+    def after(self):
         #_teardown_stdio()
         os.chdir(self._currdir)
         shutil.rmtree(self._tmpdir)
@@ -94,14 +94,14 @@ class KookMainCommandTest(object):
     def test_init(self):
         argv = ['/usr/local/bin/pykook', '-h', '-f', 'foo.py']
         obj = MainCommand(argv)
-        ok(obj.command, '==', 'pykook')
-        ok(obj.args, '==', ['-h', '-f', 'foo.py'])
+        ok (obj.command) == 'pykook'
+        ok (obj.args) == ['-h', '-f', 'foo.py']
 
     def test_nokookbook(self):  # 'Kookbook.py' not found
         soutput, eoutput, status = _main_command("pykook")
-        ok(soutput, '==', "")
-        ok(eoutput, '==', "pykook: Kookbook.py: not found.\n")
-        ok(status, '==', 1)
+        ok (soutput) == ""
+        ok (eoutput) == "pykook: Kookbook.py: not found.\n"
+        ok (status) == 1
 
     def test_noargs(self):  # 'Kookbook.py' not found
         input = r"""
@@ -110,12 +110,12 @@ class KookMainCommandTest(object):
         expected = r"""
 *** pykook: target is not given
 *** 'pykook -l' or 'pykook -L' shows recipes and properties.
-*** (or set 'kook_default_product' in your kookbook.)
+*** (or set 'kookbook.default="XXX"' in your kookbook.)
 """[1:]
         soutput, eoutput, status = _main_command("pykook")
-        ok(soutput, '==', "")
-        ok(eoutput, '==', expected)
-        ok(status, '==', 1)
+        ok (soutput) == ""
+        ok (eoutput) == expected
+        ok (status) == 1
 
     def test_help(self): # -h
         expected = r"""
@@ -135,20 +135,20 @@ pykook - build tool like Make, Rake, Ant, or Cook
 """[1:]
         ## -h
         soutput, eoutput, status = _main_command("pykook -h")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
-        ok(status, '==', 0)
+        ok (soutput) == expected
+        ok (eoutput) == ""
+        ok (status) == 0
         ## --help
         soutput, eoutput, status = _main_command("pykook --help")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
-        ok(status, '==', 0)
+        ok (soutput) == expected
+        ok (eoutput) == ""
+        ok (status) == 0
 
     def test_version(self): # -V
         soutput, eoutput, status = _main_command("pykook -V")
-        ok(soutput, '=~', r'^\d+\.\d+\.\d+$')
-        ok(eoutput, '==', "")
-        ok(status, '==', 0)
+        ok (soutput).matches(r'^\d+\.\d+\.\d+$')
+        ok (eoutput) == ""
+        ok (status) == 0
 
     def test_debug(self): # -D[N]
         input = r"""
@@ -169,8 +169,8 @@ $ echo YES
 YES
 """[1:]
         soutput, eoutput, status = _main_command("pykook echo")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## with -D
         expected = r"""
 *** debug: + begin echo
@@ -181,16 +181,16 @@ YES
 *** debug: + end echo (content changed)
 """[1:]
         try:
-            ok(config.debug_level, '==', 0)
+            ok (config.debug_level) == 0
             soutput, eoutput, status = _main_command("pykook -D echo")
-            ok(config.debug_level, '==', 1)
-            ok(soutput, '==', expected)
-            ok(eoutput, '==', "")
+            ok (config.debug_level) == 1
+            ok (soutput) == expected
+            ok (eoutput) == ""
         finally:
             config.debug_level = 0
         ## with -D
         expected = r"""
-*** debug: specific task recipes: [<TaskRecipe:'all':all>, <TaskRecipe:'echo':task_echo>]
+*** debug: specific task recipes: [<Recipe:'all':all>, <Recipe:'echo':task_echo>]
 *** debug: generic  task recipes: []
 *** debug: specific file recipes: []
 *** debug: generic  file recipes: []
@@ -205,11 +205,11 @@ YES
 *** debug: + end echo (content changed)
 """[1:]
         try:
-            ok(config.debug_level, '==', 0)
+            ok (config.debug_level) == 0
             soutput, eoutput, status = _main_command("pykook -D2 echo")
-            ok(config.debug_level, '==', 2)
-            ok(soutput, '==', expected)
-            ok(eoutput, '==', "")
+            ok (config.debug_level) == 2
+            ok (soutput) == expected
+            ok (eoutput) == ""
         finally:
             config.debug_level = 0
 
@@ -232,18 +232,18 @@ def task_echo(c):
 $ echo YES
 YES
 """[1:]
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## with '-q'
         expected = r"""
 YES
 """[1:]
         try:
-            ok(config.quiet, '==', False)
+            ok (config.quiet) == False
             soutput, eoutput, status = _main_command("pykook -q echo")
-            ok(config.quiet, '==', True)
-            ok(soutput, '==', expected)
-            ok(eoutput, '==', "")
+            ok (config.quiet) == True
+            ok (soutput) == expected
+            ok (eoutput) == ""
         finally:
             config.quiet = False
 
@@ -267,8 +267,8 @@ $ echo No
 No
 """[1:]
         soutput, eoutput, status = _main_command("pykook print")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## with -f
         expected = r"""
 ### * print (recipe=task_print)
@@ -276,12 +276,12 @@ $ echo Yes
 Yes
 """[1:]
         soutput, eoutput, status = _main_command("pykook -f Kookbook2.py print")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## if not found
         soutput, eoutput, status = _main_command("pykook -f Kookbook3.py print")
-        ok(soutput, '==', "")
-        ok(eoutput, '==', "pykook: -f Kookbook3.py: not found.\n")
+        ok (soutput) == ""
+        ok (eoutput) == "pykook: -f Kookbook3.py: not found.\n"
 
     def test_forced(self): # -F
         input = r"""
@@ -296,19 +296,19 @@ def file_html(c):
         write_file("index.txt", "foobar")
         ## recipe should not be invoked because product is newer
         soutput, eoutput, status = _main_command("pykook index.html")
-        ok(soutput, '==', "")
-        ok(eoutput, '==', "")
+        ok (soutput) == ""
+        ok (eoutput) == ""
         ## recipe should be invoked when -F specified
         expected = r"""
 ### * index.html (recipe=file_html)
 $ cp index.txt index.html
 """[1:]
         try:
-            ok(config.forced, '==', False)
+            ok (config.forced) == False
             soutput, eoutput, status = _main_command("pykook -F index.html")
-            ok(config.forced, '==', True)
-            ok(soutput, '==', expected)
-            ok(eoutput, '==', "")
+            ok (config.forced) == True
+            ok (soutput) == expected
+            ok (eoutput) == ""
         finally:
             config.forced = False
 
@@ -331,24 +331,24 @@ def file_html(c):
         ## products should not be created!
         try:
             soutput, eoutput, status = _main_command("pykook -n index.xhtml")
-            ok(config.noexec, '==', True)
+            ok (config.noexec) == True
         finally:
             config.noexec = False
-        ok('indent.html', os.path.isfile, False)
-        ok('indent.xhtml', os.path.isfile, False)
+        not_ok ('indent.html').is_file()
+        not_ok ('indent.xhtml').is_file()
         expected = r"""
 ### ** index.html (recipe=file_html)
 $ cp index.txt index.html
 ### * index.xhtml (recipe=file_xhtml)
 $ cp index.html index.xhtml
 """[1:]
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_list(self): # -l, -L
         input = r"""
 CC = prop('CC', 'gcc')
-kook_default_product = 'all'
+kookbook.default = 'all'
 
 @recipe
 @ingreds('hello')
@@ -356,7 +356,7 @@ def task_all(c):           # well-known recipe
   pass
 
 @recipe
-@spices('-h: help', '-f file: filename')
+@spices('-h: help', '-f file: filename', '-x:', '-y: ', '-z', '[files...]')
 def install(c, *args, **kwargs):        # with spices
   pass
 
@@ -379,7 +379,7 @@ Properties:
 
 Task recipes:
   all                 : cook all products
-  install             : install product
+  install [files...]  : install product
     -h                    help
     -f file               filename
 
@@ -387,7 +387,7 @@ File recipes:
   hello               : build hello command
   *.o                 : 
 
-kook_default_product: all
+kookbook.default: all
 
 (Tips: you can override properties with '--propname=propvalue'.)
 """[1:]
@@ -395,14 +395,14 @@ kook_default_product: all
         ## -l
         soutput, eoutput, status = _main_command("pykook -l")
         soutput  = re.sub(r'\n\(Tips:.*\n', '\n', soutput)
-        ok(soutput, '==', re.sub(r'\n  \*\.o.*\n', '\n', expected))
-        ok(eoutput, '==', "")
+        ok (soutput) == re.sub(r'\n  \*\.o.*\n', '\n', expected)
+        ok (eoutput) == ""
         ## -L
         soutput, eoutput, status = _main_command("pykook -L")
         soutput  = re.sub(r'\n\(Tips:.*\n', '\n', soutput)
         expected = re.sub(r'\n\(Tips:.*\n', '\n', expected)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_properties(self): # --name=value
         input = r"""
@@ -420,8 +420,8 @@ CC=tcc, VERBOSE=True
 """[1:]
         ## '--CC=tcc' overrides property value, '--verbose' is regards as '--verbose=True'
         soutput, eoutput, status = _main_command("pykook --CC=tcc --verbose echo")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_property_file(self):  # Properties.py
         input = r"""
@@ -448,8 +448,8 @@ $ echo VERBOSE=False
 VERBOSE=False
 """[1:]
         soutput, eoutput, status = _main_command("pykook echo")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## Properties.py is reflected to output of '-l' or '-L'
         expected = r"""
 Properties:
@@ -461,13 +461,13 @@ Task recipes:
 
 File recipes:
 
-(Tips: you can set 'kook_default_product' variable in your kookbook.)
+(Tips: you can set 'kookbook.default="XXX"' variable in your kookbook.)
 """[1:]
         soutput, eoutput, status = _main_command("pykook -L")
         soutput  = re.sub(r'\n\(Tips:.*\n', '\n', soutput)
         expected = re.sub(r'\n\(Tips:.*\n', '\n', expected)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## command-line option is prior than Properties.py
         expected = r"""
 ### * echo (recipe=task_echo)
@@ -477,8 +477,8 @@ $ echo VERBOSE=32
 VERBOSE=32
 """[1:]
         soutput, eoutput, status = _main_command("pykook --CC=g++ --VERBOSE=32 echo")
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_spices(self):  # @spices
         input = r"""
@@ -498,8 +498,8 @@ args=('foo', 'bar')
 $ echo kwargs={'i': 2, 'h': True, 'v': True, 'f': 'file.txt'}
 kwargs={'i': 2, 'h': True, 'v': True, 'f': 'file.txt'}
 """[1:]
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         ## -L shows spices (command options)
         expected = r"""
 Properties:
@@ -518,8 +518,8 @@ File recipes:
         soutput, eoutput, status = _main_command("pykook -L")
         soutput  = re.sub(r'\n\(Tips:.*\n', '\n', soutput)
         expected = re.sub(r'\n\(Tips:.*\n', '\n', expected)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def ktest_search_recursively(self):
         curr_dir = os.getcwd()
@@ -538,8 +538,8 @@ def cwd(c):
             os.chdir(tmp_dir)
             #
             soutput, eoutput, status = _main_command("pykook cwd")
-            ok(soutput, '==', "")
-            ok(eoutput, '==', "pykook: Kookbook.py: not found.\n")
+            ok (soutput) == ""
+            ok (eoutput) == "pykook: Kookbook.py: not found.\n"
             #
             expected = r'''
 ### * cwd (recipe=cwd)
@@ -547,8 +547,8 @@ $ echo cwd=/Users/kwatch/src/kook2/python/%s
 cwd=/Users/kwatch/src/kook2/python/%s
 '''[1:] % (tmp_root, tmp_root)
             soutput, eoutput, status = _main_command("pykook -R cwd")
-            ok(soutput, '==', expected)
-            ok(eoutput, '==', "")
+            ok (soutput) == expected
+            ok (eoutput) == ""
             #
         finally:
             os.chdir(curr_dir)
@@ -605,11 +605,11 @@ class KookMainApplicationTest(object):
     def after_all(self):
         if os.path.isfile(APPNAME): os.unlink(APPNAME)
 
-    def before_each(self):
+    def before(self):
         #_setup_stdio()
         pass
 
-    def after_each(self):
+    def after(self):
         #_teardown_stdio()
         if hasattr(self, 'byprods'):
             for x in self.byprods:
@@ -619,8 +619,8 @@ class KookMainApplicationTest(object):
     def test_init(self):
         argv = ["pykook", "-X", APPNAME, "-h"]
         app = MainApplication(argv)
-        ok(app.command, '==', None)
-        ok(app.args, '==', argv[1:])
+        ok (app.command) == None
+        ok (app.args) == argv[1:]
 
     def test_help_all(self): # -h
         expected = r"""
@@ -634,8 +634,8 @@ sub-commands:
 (Type 'hello -h subcommand' to show options of sub-commands.)
 """[1:]
         soutput, eoutput, status = _main_app("pykook -X %s -h" % APPNAME)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_help_subcommand(self): # -h command
         #
@@ -645,64 +645,64 @@ hello setup - setup configuration
   --prefix=path        : install path
 """[1:]
         soutput, eoutput, status = _main_app("pykook -X %s -h setup" % APPNAME)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         #
         expected = r"""
 hello build - compile files
   --cflags=opts        : compiler options
 """[1:]
         soutput, eoutput, status = _main_app("pykook -X %s -h build" % APPNAME)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         #
         expected = r"""
 hello install - install files
 """[1:]
         soutput, eoutput, status = _main_app("pykook -X %s -h install" % APPNAME)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_no_subommand(self): #
         expected = "%s: sub-command is required (try '-h' to show all sub-commands).\n" % APPNAME
         soutput, eoutput, status = _main_app("pykook -X %s" % APPNAME)
-        ok(soutput, '==', "")
-        ok(eoutput, '==', expected)
+        ok (soutput) == ""
+        ok (eoutput) == expected
 
     def test_subcommand(self):
         command = "pykook -X %s setup" % APPNAME
         expected = "setup(): args=(), kwargs={}\n"
         soutput, eoutput, status = _main_app(command)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         #
         command = "pykook -X %s setup aaa bbb" % APPNAME
         expected = "setup(): args=('aaa', 'bbb'), kwargs={}\n"
         soutput, eoutput, status = _main_app(command)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
         #
         command = "pykook -X %s setup -d/tmp --prefix=/usr/local aaa bbb" % APPNAME
         expected = "setup(): args=('aaa', 'bbb'), kwargs={'prefix': '/usr/local', 'd': '/tmp'}\n"
         soutput, eoutput, status = _main_app(command)
-        ok(soutput, '==', expected)
-        ok(eoutput, '==', "")
+        ok (soutput) == expected
+        ok (eoutput) == ""
 
     def test_unknown_subcommand_option(self):
         command = "pykook -X %s setup -j" % APPNAME
         expected = "%s: setup(): -j: unknown command option.\n" % APPNAME
         soutput, eoutput, status = _main_app(command)
-        ok(soutput, '==', "")
-        ok(eoutput, '==', expected)
+        ok (soutput) == ""
+        ok (eoutput) == expected
 
     def test_unknown_global_option(self):
         command = "pykook -j %s setup" % APPNAME
         expected = "-j: unknown command option.\n"
         soutput, eoutput, status = _main_app(command)
-        ok(soutput, '==', "")
-        ok(eoutput, '==', expected)
+        ok (soutput) == ""
+        ok (eoutput) == expected
 
 
 
 if __name__ == '__main__':
-    oktest.invoke_tests('Test$')
+    oktest.run('.*Test$')
